# madenntools
MaDENN Computer Vision toolkit.

Work in progress - more tools and documentation to come. 

Available namespaces:
- madenntools.cv
- madenntools.metric
- madenntools.plot

## Install
```
pip install madenntools
```

### Documentation

- [Library documentation](https://github.com/MaDENN-AI/madenntools/blob/main/doc/library_documentation.md)
- [Usage](https://github.com/MaDENN-AI/madenntools/blob/main/doc/usage.md)
- [Package update](https://github.com/MaDENN-AI/madenntools/blob/main/doc/update.md)
- [Contribution](https://github.com/MaDENN-AI/madenntools/blob/main/doc/contrib.md)